@@ -120,6 +120,24 @@ void doxschema(xcWidget w, pointertype mode, caddr_t calldata)
    if (mode) drawarea(NULL, NULL, NULL);
 }
 
+/*----------------------------------------------------------------------*/
+/* Find the page object and instance with the indicated name.		*/
+/*----------------------------------------------------------------------*/
+
+objectptr NameToPageObject(char *objname, objinstptr *ret_inst)
+{
+   int i;
+
+   for (i = 0; i < xobjs.pages; i++) {
+      if (xobjs.pagelist[i]->pageinst == NULL) continue;
+      if (!strcmp(objname, xobjs.pagelist[i]->pageinst->thisobject->name)) {
+	 if (ret_inst) *ret_inst = xobjs.pagelist[i]->pageinst;
+	 return xobjs.pagelist[i]->pageinst->thisobject;
+      }
+   }
+   return NULL;
+}
+
 /*----------------------------------------------------------------------*/
 /* Find the object with the indicated name.				*/
 /*----------------------------------------------------------------------*/
@@ -138,17 +156,10 @@ objectptr NameToObject(char *objname, objinstptr *ret_inst, Boolean dopages)
       }
    }
 
-   if (dopages) {
-      for (i = 0; i < xobjs.pages; i++) {
-	 if (xobjs.pagelist[i]->pageinst == NULL) continue;
-	 if (!strcmp(objname, xobjs.pagelist[i]->pageinst->thisobject->name)) {
-	    if (ret_inst) *ret_inst = xobjs.pagelist[i]->pageinst;
-	    return xobjs.pagelist[i]->pageinst->thisobject;
-	 }
-      }
-   }
-   
-   return NULL;
+   if (dopages)
+      return NameToPageObject(objname, ret_inst);
+   else
+      return NULL;
 }
 
 /*------------------------------------------------------------------------*/
@@ -228,21 +239,22 @@ void startconnect(xcWidget button, caddr_t clientdata, caddr_t calldata)
 /*----------------------------------------------------------------------*/
 /* connectivity():  Find electrical connections into a node.		*/
 /* (does recursive search on object heirarchy)				*/
-/* Returns net number found (0 if no network found, -1 if error)	*/
 /*----------------------------------------------------------------------*/
 
-int connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
+void connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
 {
    short *gsel;
    genericptr ggen;
-   int depth, netid = -1;
+   Genericlist *netlist = NULL;
+   int depth, lbus, netid, subnetid;
+   buslist *sbus;
    pushlistptr seltop, nextptr;
    objectptr nettop, thisobj;
    char *snew;
    stringpart *ppin;
 
    /* erase any existing highlighted network */
-   highlightnet(topobject, areastruct.topinstance, -1, 0);
+   highlightnetlist(topobject, areastruct.topinstance, 0);
 
    seltop = (pushlistptr)malloc(sizeof(pushlist));
    seltop->thisinst = areastruct.topinstance;
@@ -270,7 +282,7 @@ int connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
    else
       ggen = recurselect(POLYGON | LABEL, &seltop);
 
-   /* Determine the netid and the topmost object in which that	*/
+   /* Determine the net and the topmost object in which that	*/
    /* net appears.  Then build the transformation matrix down	*/
    /* to that object.  highlightnet() should end by popping the */
    /* entire matrix stack.					*/
@@ -280,35 +292,50 @@ int connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
          destroynets(topobject);
          createnets(areastruct.topinstance);
       }
-      if ((netid = is_resolved(&ggen, seltop, &nettop)) != 0) {
-         /* Fprintf(stdout, "Net ID is %d in object %s\n", netid, nettop->name); */
+      if ((netlist = is_resolved(&ggen, seltop, &nettop)) != NULL) {
          depth = pushnetwork(seltop, nettop);
          /* Fprintf(stdout, ">> Pushed network %d levels deep\n", depth); */
          nextptr = seltop;
          while (nextptr->thisinst->thisobject != nettop)
 	    nextptr = nextptr->next;
 
-	 nextptr->thisinst->thisobject->highlight.netid = netid;
+	 nextptr->thisinst->thisobject->highlight.netlist = netlist;
 	 nextptr->thisinst->thisobject->highlight.thisinst = nextptr->thisinst;
+	 highlightnetlist(nettop, nextptr->thisinst, 1);
 	    
-         highlightnet(nettop, nextptr->thisinst, netid, 1);
-
          /* pop the matrix stack */
          while (depth-- > 0) 
 	    UPopCTM();
 
 	 /* print the net name to the message window */
 
-	 ppin = nettopin(netid, nettop, NULL);
-         snew = textprint(ppin, areastruct.topinstance);
-
-	 sprintf(_STR, "Network is \"%s\" in %s", snew, nettop->name);
-	 Wprintf(_STR);
+	 if (netlist->subnets == 0) {
+	    ppin = nettopin(netlist->net.id, nettop, NULL);
+            snew = textprint(ppin, areastruct.topinstance);
+	    sprintf(_STR2, "Network is \"%s\" in %s", snew, nettop->name);
+            free(snew);
+	 }
+	 else {
+	    char *sptr;
+	    sprintf(_STR2, "Network(s): ");
+	    sptr = _STR2 + strlen(_STR2);
+	    for (lbus = 0; lbus < netlist->subnets; lbus++) {
+	       sbus = netlist->net.list + lbus;
+	       netid = sbus->netid;
+	       subnetid = sbus->subnetid;
+	       ppin = nettopin(netid, nettop, NULL);
+               snew = textprintsubnet(ppin, areastruct.topinstance, subnetid);
+	       sprintf(sptr, "%s ", snew);
+	       sptr += strlen(snew) + 1;
+	       free(snew);
+	    }
+	    sprintf(sptr, "in %s", nettop->name);
+	 }
+	 Wprintf(_STR2);
 
 #ifdef TCL_WRAPPER
 	 Tcl_SetObjResult(xcinterp, Tcl_NewStringObj(snew, strlen(snew)));
 #endif
-         free(snew);
       }
       else
 	 Wprintf("Selected element is not part of a valid network.");
@@ -325,7 +352,6 @@ int connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
       free(seltop);
       seltop = nextptr;
    }
-   return netid;
 }
 
 /*--------------------------------------------------------------*/
@@ -1049,14 +1075,7 @@ void startschemassoc(xcWidget w, pointertype mode, caddr_t calldata)
 
 Boolean schemassoc(objectptr schemobj, objectptr symbolobj)
 {
-   if (eventmode != ASSOC_MODE) {
-      Wprintf("Cannot make (dis)association in this mode");
-#if TCL_WRAPPER
-      Tcl_SetResult(xcinterp, "Cannot make association in this mode.", NULL);
-#endif
-      return False;
-   }
-   else if (schemobj->symschem != NULL || symbolobj->symschem != NULL) {
+   if (schemobj->symschem != NULL || symbolobj->symschem != NULL) {
       Wprintf("Both objects must be disassociated first.");
 #if TCL_WRAPPER
       Tcl_SetResult(xcinterp, "Both objects must be disassociated first.", NULL);
